@@ -25,22 +25,25 @@ __all__ = ['download_vfb_transforms', 'download_jefferislab_transforms',
            'download_jrc_transforms', 'download_jrc_vnc_transforms']
 
 
-def download_vfb_transforms(repos=("VfbBridgingRegistrations"),
+def download_vfb_transforms(repos=("VfbBridgingRegistrations", ),
                                    update_existing=True,
                                    use_ssh=False,
                                    data_home=None):
     """Download VirtualFlyBrain.org (VFB) CMTK transforms.
 
     BridgingRegistrations (~6Mb):
-      - JRCVNC2018U_JRCVNC2018F: JRC2018-VNC-UNISEX-4iso -> JRC2018-VNC-FEMALE-4iso
-      - JRCVNC2018M_JRCVNC2018U: JRC2018_VNC_MALE_4iso -> JRC2018_VNC_UNISEX_4iso
       - COURT2017VNS_JRCVNC2018F: DrosAdultVNSdomains_Court2017_template_Neuropil_LPS -> JRC2018_VNC_FEMALE_4iso_LPS
       - COURT2018VNS_JRCVNC2018U: 20x_flyVNCtemplate_Female_symmetric -> JRC2018_VNC_UNISEX_4iso
 
+    Important
+    ---------
+    The VFB CMTK transforms _between_ JRCVNC2018 template brains were removed
+    in version 0.2.10 as they no longer available for download. Please use the
+    JRC H5 transforms from the Saalfeld lab instead.
 
     Parameters
     ----------
-    repos :             "BridgingRegistrations" list thereof
+    repos :             "VfbBridgingRegistrations" | list of str
                         Which registrations to download. These are Github
                         repositories (e.g. ``VirtualFlyBrain/VfbBridgingRegistrations``)
                         which will be cloned into ``~/flybrain-data/``.
@@ -106,13 +109,13 @@ def download_jefferislab_transforms(repos=("BridgingRegistrations",
       - VNCIS1 <-> V2
       - JFRC2013DS <-> JFRC2013
       - JFRC2 <-> IS2
+      - JRC2018F <-> FLYWIRE
 
     MirrorRegistrations (~40Mb):
       - ATAG
       - FCWB
       - IS2
       - JFRC2
-      - JFRC2
       - JFRC
       - T1
       - V2
@@ -243,14 +246,16 @@ def download_jrc_transforms(data_home=None, skip_existing=True):
     https://www.janelia.org/open-science/jrc-2018-brain-templates
 
     Includes:
-      - JRC2018 <-> FAFB
+      - JRC2018F <-> FAFB
       - JRC2018F <-> JFRC2013
       - JRC2018F <-> FCWB
       - JRC2018F <-> JRCFIB2018F (hemibrain)
       - JRC2018U <-> JRC2018F
+      - JRC2018U <-> JRC2018M
       - JRC2018F <-> JFRC2010
+      - JRC2018M <-> JRCFIB2022M (maleCNS)
 
-    Note that these transforms are fairly large: between 550Mb and 1.4Gb each.
+    Note that these transforms are fairly large: between 550Mb and 2Gb each.
 
     Parameters
     ----------
@@ -271,7 +276,8 @@ def download_jrc_transforms(data_home=None, skip_existing=True):
         "21749535?private_link=ca603876efb33fdf3028",
         "14371574?private_link=b7120207f38b35f1e372",
         "14448911?private_link=2afde323b12274d3243b",
-        "14368358?private_link=b29e25b6e47ccf9187a8"
+        "14368358?private_link=b29e25b6e47ccf9187a8",
+        "42106125?private_link=bfbfc18d24fe959b78c0",
             )
     urls = [f"https://ndownloader.figshare.com/files/{f}" for f in urls]
 
@@ -282,7 +288,8 @@ def download_jrc_transforms(data_home=None, skip_existing=True):
         'JRC2018F_JRCFIB2018F.h5',
         'JRC2018U_JRC2018F.h5',
         'JRC2018U_JRC2018M.h5',
-        'JRC2018F_JFRC2010.h5'
+        'JRC2018F_JFRC2010.h5',
+        'JRCFIB2022M_JRC2018M.h5'  # originally: MaleCNS_JRC2018M_d2.h5
       )
 
     print(f'Downloading JRC (Saalfeld lab) brain transforms into {data_home}')
@@ -303,6 +310,7 @@ def download_jrc_vnc_transforms(data_home=None, skip_existing=True):
     Includes:
       - JRCVNC2018U <-> JRCVNC2018F (110Mb)
       - JRCVNC2018U <-> JRCVNC2018M (150Mb)
+      - JRCVNC2018M <-> MANC (1Gb)
 
     Parameters
     ----------
@@ -318,13 +326,15 @@ def download_jrc_vnc_transforms(data_home=None, skip_existing=True):
     data_home = get_data_home(data_home, create=True)
     urls = (
         "28909212?private_link=c4589cef9180e1dd4ee1",
-        "28908795?private_link=42ad71eb14e7dd51e81a")
+        "28908795?private_link=42ad71eb14e7dd51e81a",
+        "38827794")
     urls = [f"https://ndownloader.figshare.com/files/{f}" for f in urls]
 
     # Note that we are renaming the files upon download!
     filenames = (
         'JRCVNC2018U_JRCVNC2018F.h5',  # originally: JRC2018VncU_JRC2018VncF.h5
         'JRCVNC2018M_JRCVNC2018U.h5',  # originally: JRC2018VncM_JRC2018VncU.h5
+        'JRCVNC2018M_MANC.h5',  # originally: JRC2018VncM_MANC.h5
       )
 
     print(f'Downloading JRC (Saalfeld lab) VNC transforms into {data_home}')
